NotFoundError class

404 Not Found - resource doesn't exist

Inheritance

Constructors

NotFoundError([String resource = 'Resource'])
Creates a not found error.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP status code
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert to JSON response format
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited